# Firefox

Profile configuration that can be set up directly within profile folders. Configuration is the same across version, devices, and profiles, excepting a few settings adjusted manually.

## Setup

1. Change browser theme at `about:addons#themes`
2. Set up Firefox sync at `about:preferences#sync`
3. Install and configure shared extensions
	- [uBlock Origin](https://addons.mozilla.org/firefox/addon/ublock-origin/)
		- **Import from Firefox Sync**
		- `Enable cloud storage support` = `true`
		- `Custom filters` =
			- <https://raw.githubusercontent.com/DandelionSprout/adfilt/master/LegitimateURLShortener.txt>
			- <https://git.ashtonc.ca/ashton/ubo-filters/raw/branch/main/ubo-filters.txt>
	- [Multi-Account Containers](https://addons.mozilla.org/firefox/addon/multi-account-containers/)
		- Default = `[ "Work (Blue/Circle)" ]`
		- Work = `[ "Personal (Green/Circle)" ]`
	- [Temporary Containers](https://addons.mozilla.org/firefox/addon/temporary-containers/)
		- **Import from Firefox Sync**
		- `Container Name Prefix` = `T`
		- `Container Number` = `Reuse available numbers`
		- `Context Menu` = `false`
		- `Keyboard shorcuts` = `[ "Alt+C", "Alt+X", "Alt+O" ]`
		- Add shortcut to toolbar
	- [Hover Zoom+](https://addons.mozilla.org/firefox/addon/hover-zoom-plus/)
		- `Use prev/next action keys (or mousewheel) to change video position by` = `4`
		- `Show timestamp on videos` = `true`
		- `Audio volume for unmuted videos` = `100`
		- `Play audio sources such as MP3` = `true`
		- `Audio volume` = `100`
		- `Delays` = `0`
		- `Action keys` = `[ "Close", "View previous", "View next" ]`
		- `Add viewed pictures to the browser's history` = `true`
		- `Allow rewrite of headers for HTTP(S) request or response` = `true`
	- [Tridactyl](https://addons.mozilla.org/firefox/addon/tridactyl-vim/)
	- [Bypass Paywalls Clean](https://github.com/bpc-clone/bypass-paywalls-firefox-clean)
		- `Opt-in` = `enable`
4. Install and configure additional extensions
	- [Sponsorblock](https://addons.mozilla.org/firefox/addon/sponsorblock/)
	- [DeArrow](https://addons.mozilla.org/firefox/addon/dearrow/)
		- `"3rdparty"."Extensions"."deArrow@ajay.app"."licenseKey" = "$key"`
	- [Torrent Control](https://addons.mozilla.org/en-CA/firefox/addon/torrent-control/)
	- [Reddit Enhancement Suite](https://addons.mozilla.org/firefox/addon/reddit-enhancement-suite/)
	- [KeePassXC-Browser](https://addons.mozilla.org/firefox/addon/keepassxc-browser/)

## To do

- Add `policies.json` file to this repo
- Move from [Vimium C](https://github.com/gdh1995/vimium-c) to [Tridactyl](https://github.com/tridactyl/tridactyl) and set up `.tridactylrc`
- Native messaging integration
	- Play videos in mpv via hotkey
	- Shortcut for external text editor
	- Control browser instance via devtools protocol (playwright)
- Disable and reuse reserved keyboard shortcuts (probably requires a patch)
- Enable `ctrl+[1-9]` shortcuts on Linux
- Review quick navigation shortcuts
	- Pages: specific pages, previously closed, last visited
	- Tabs: move, pop out, close, duplicate
	- Screenshots: full page, certain area, zoomed
	- Bookmark or create note to revisit a tab
	- Search, navigate, etc. (most recent tab, regex search, spacial navigation)
- Reduce context menu size
- Export bookmarks and history
- Bookmark tagging and import/export

## Reference

- [arkenfox](https://github.com/arkenfox/user.js)
- [Betterfox](https://github.com/yokoffing/Betterfox)
- Styles
	- <https://github.com/AveYo/fox>
	- <https://github.com/MrOtherGuy/firefox-csshacks>
	- <https://github.com/black7375/Firefox-UI-Fix>
	- <https://github.com/xarantolus/userchrome.css>
- Scripts
	- <http://kb.mozillazine.org/Profile_folder_-_Firefox>
	- <https://www.userchrome.org/what-is-userchrome-js.html>
	- <https://github.com/xiaoxiaoflood/firefox-scripts>
	- <https://github.com/MrOtherGuy/fx-autoconfig>
	- <https://greasyfork.org/en/scripts/431691-bypass-all-shortlinks>
	- <https://greasyfork.org/en/scripts/427254-preventpagevisibility>
	- <https://greasyfork.org/en/scripts/429635-always-on-focus>
